package com.app

import com.vaadin.annotations.Theme
import com.vaadin.ui.Notification
import com.vaadin.ui.UI
import com.vaadin.ui.VerticalLayout
import com.vaadin.server.VaadinRequest
import com.vaadin.ui.Label
import com.vaadin.grails.Grails
import groovy.transform.CompileStatic
import org.apache.commons.logging.Log
import org.apache.commons.logging.LogFactory
import org.percepta.mgrankvi.TimeSelector
import java.time.LocalTime
import java.time.format.DateTimeFormatter


@CompileStatic
@Theme('mytheme')
class MyUI extends UI {

    TimeSelector time
    Log log
    DateTimeFormatter timFmt

    MyUI() {
        log = LogFactory.getLog(this.class)
        log.info "CONSTRUCTOR"
        timFmt = DateTimeFormatter.ofPattern('HH:mm')
    }

    @Override
    protected void init(VaadinRequest vaadinRequest) {
        log.info "init()"

		VerticalLayout layout = new VerticalLayout()
        layout.margin = true

        String homeLabel = Grails.i18n("default.home.label")
        Label label = new Label(homeLabel)
        label.styleName = "h1"
        layout.addComponent label

        time = new TimeSelector(caption: 'click on the time to open the TimeSelector:')
        time.width = "5em"
        time.value = LocalTime.now()
        time.twentyFour = true
        time.minuteSectors = 12
        time.setMinuteCaptions(5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 0)
        // or groovy'isch =:-)
        //      time.minuteCaptions = (Integer[]) [5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 0].toArray()
        //      time.minuteCaptions = (Integer[]) ((1..11).collect{it*5} +0).toArray()
        // without @CompileStatic
        //      time.minuteCaptions = [5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 0].toArray()
        time.addValueChangeListener { evt ->
            String tStr = "Time set: ${time.value.format(timFmt)}"
            Notification.show tStr
            log.info tStr
        }
        layout.addComponent time

		this.content = layout
    }
}
